@@ -10,6 +10,9 @@ from .observer_kalman_identification_algorithm import *
 from .observer_kalman_identification_algorithm_with_observer import *
 from .polynomial_basis_functions import *
 from .polynomial_index import *
+from .propagate import *
+from .runge_kutta_45 import *
+from .state_transition_tensor_propagation import *
 from .time_invariant_koopman_operator import *
 from .time_varying_eigensystem_realization_algorithm import *
 from .time_varying_eigensystem_realization_algorithm_from_initial_condition_response import *
