@@ -9,11 +9,12 @@ Version: 24
 import numpy as np
 from scipy.integrate import odeint
 
+from systemID.signals.discrete import discrete_signal
 from systemID.functions.runge_kutta_45 import runge_kutta_45
 from systemID.functions.state_transition_tensor_propagation import state_transition_tensor_propagation
 
 
-def propagation(signal, system, **kwargs):
+def propagate(signal, system, **kwargs):
     """
     Purpose:
 
@@ -400,4 +401,7 @@ def propagation(signal, system, **kwargs):
                 y[:, i] = G(x[:, i], tspan[i], signal.u(tspan[i]))
 
 
-    return y, x
+    output_signal = discrete_signal(frequency=signal.frequency, data=y)
+    state = discrete_signal(frequency=signal.frequency, data=x)
+
+    return output_signal, state
